.. _examples_modelling_cbed_simulations_sec:

Examples of CBED multislice simulations
=======================================

Below are links to some code examples of "actions" that are related to
multislice simulations of convergent beam electron diffraction (CBED)
experiments, including: the generation of the atomic coordinates of certain
sample models; the generation of the potential slices of certain sample models;
and the generation of CBED patterns.

.. toctree::

   simulations/MoS2/generate_atomic_coords.rst
   simulations/amorphous_C_superblock/generate_atomic_coords.rst
   simulations/MoS2_on_amorphous_C/generate_atomic_coords.rst
   simulations/MoS2_on_amorphous_C/generate_potential_slices.rst
   simulations/MoS2_on_amorphous_C/generate_cbed_pattern_sets.rst
